==> haskell-constraints-extras-0.4.0.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-HVHrc9KYEsl77Jwj4p0eTw
key:                  constraints-extras-0.4.0.1-HVHrc9KYEsl77Jwj4p0eTw
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  8151a3da67c01953c267d27427f6ddf8
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-HVHrc9KYEsl77Jwj4p0eTw
depends:
    base-4.16.4.0 constraints-0.13.4-KDDgyC3O9lNGfh8gQcs6tR
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.4.0.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-KY1lrjY5XOE1QN8Ft6PXX6
key:                  constraints-extras-0.4.0.1-KY1lrjY5XOE1QN8Ft6PXX6
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  eac7a018893245fcaa36c057c1587168
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-KY1lrjY5XOE1QN8Ft6PXX6
depends:
    base-4.16.4.0 constraints-0.13.4-IztSiuX4DPZF7e5JDoiZCq
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
